clear
set more off
use ..\cdata\finaldataseta.dta


*THE COMMANDS IN THIS DO-FILE GENERATE THE RESULTS REPORTED IN THE PAPER.

******************************************************************************************
********First for the results pertaining to Methodology A***********************************
******************************************************************************************

*TABLE 1
**running some summary statistics to acquaint the reader with the data
tabstat dollars avgyrlcontract aicy duration wscy ws2cy ws1cy wscy1 wscy2 if wscy!=. & ws2cy!=. & ws1cy!=.  & wscy1!=. & wscy2!=., stat(mean sd p25 p50 p75 min max) 

*TABLE 2
**generating summary statistics by contract length
sort duration
by duration: tabstat dollars avgyrlcontract aicy ws2cy ws1cy wscy wscy1 wscy2 if wscy!=. & ws2cy!=. & ws1cy!=.  & wscy1!=. & wscy2!=.

*TABLE 4
**running a seemingly unrelated regression to simultaneously look at future performance and get a twofold approach to running
** the contract model with duration and average yearly dollar amount estimated separately
xi: sureg (lnfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp1cy mp2cy i.tmcy i.cy) (lnavgyrlcon lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) (lnduration lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) 

*TABLE 5
**without fixed effects to illustrate the power of the explanatory variables
sureg (lnfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp1cy mp2cy) (lnavgyrlcon lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy) (lnduration lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy)

*TABLE 6
*To generate the ratios reported in Table 6, first execute the 
*the SUR regression command that generates Table 4:

quietly xi: sureg (lnfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp1cy mp2cy i.tmcy i.cy) (lnavgyrlcon lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) (lnduration lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) 

*Then execute the following commands to generate the ratios reported
*in Table 6

	*Ratio 1
		*Future performance
		display _b[#1:lnws1cya]/_b[#1:lnwscy]
		*Average contract value
		display _b[#2:lnws1cya]/_b[#2:lnwscy]
		*Contract duration
		display _b[#3:lnws1cya]/_b[#3:lnwscy]

	*Ratio 2
		*Future performance
		display _b[#1:lnws2cya]/_b[#1:lnwscy]
		*Average contract value
		display _b[#2:lnws2cya]/_b[#2:lnwscy]
		*Contract duration
		display _b[#3:lnws2cya]/_b[#3:lnwscy]
	
	
*TESTS FOR EQUALITY OF THE RATIOS PRESENTED IN TABLE 6.
*(These tests are discussed on page 30 of the thesis.)	

*First, execute the SUR regression command that generates Table 4:

quietly xi: sureg (lnfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp1cy mp2cy i.tmcy i.cy) (lnavgyrlcon lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) (lnduration lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) 

*Then in order to test the ratios of interest, I compared the ratios from one equation to those of another
*comparing one year lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws1cya]/_b[#1:lnwscy]=_b[#2:lnws1cya]/_b[#2:lnwscy]
*comparing one year lagged performance on future performance equal to contract length
testnl _b[#1:lnws1cya]/_b[#1:lnwscy]=_b[#3:lnws1cya]/_b[#3:lnwscy]

*comparing two years lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws2cya]/_b[#1:lnwscy]=_b[#2:lnws2cya]/_b[#2:lnwscy]
*comparing two years lagged performance on future performance equal to contract length
testnl _b[#1:lnws2cya]/_b[#1:lnwscy]=_b[#3:lnws2cya]/_b[#3:lnwscy]


*TESTS FOR EQUALITY OF RATIOS USING THE RESULTS OF THE REGRESSION
*WITHOUT FIXED EFECTS
*(See Footnote 10 on page 30 of the thesis.)

*First, execute the SUR regression command that generates Table 5:
quietly sureg (lnfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp1cy mp2cy) (lnavgyrlcon lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy) (lnduration lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy)

*Then in order to test the ratios of interest, I compared the ratios from one equation to those of another
*comparing one year lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws1cya]/_b[#1:lnwscy]=_b[#2:lnws1cya]/_b[#2:lnwscy]
*comparing one year lagged performance on future performance equal to contract length
testnl _b[#1:lnws1cya]/_b[#1:lnwscy]=_b[#3:lnws1cya]/_b[#3:lnwscy]

*comparing two years lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws2cya]/_b[#1:lnwscy]=_b[#2:lnws2cya]/_b[#2:lnwscy]
*comparing two years lagged performance on future performance equal to contract length
testnl _b[#1:lnws2cya]/_b[#1:lnwscy]=_b[#3:lnws2cya]/_b[#3:lnwscy]


******************************************************************************************
********Now for the results pertaining to Methodology B***********************************
******************************************************************************************

clear
set more off
use ..\cdata\finaldatasetb

*TABLE 3
**generating some summary statistics for familiarizing the reader with the data
sort duration
by duration: tabstat dollars ws2cy ws1cy wscy totfutwsDATA aicy if wscy!=. & ws2cy!=. & ws1cy!=.  & totfutwsDATA!=. 

*TABLE 7
**running a seemingly unrelated regression to simultaneously model the impact of past performance on future performance and contract
xi: sureg (lntotfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) (lndollars lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy)

*TABLE 8
**without fixed effects to check for impact on R^2
sureg (lntotfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy) (lndollars lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy)

*TABLE 9
*To generate the ratios reported in Table 9, first execute the 
*the SUR regression command that generates Table 7:

quietly xi: sureg (lntotfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) (lndollars lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy)

*Then execute the following commands to generate the ratios reported
*in Table 6

	*Ratio 1
		*Total future win shares
		display _b[#1:lnws1cya]/_b[#1:lnwscy]
		*Total contract value
		display _b[#2:lnws1cya]/_b[#2:lnwscy]
		

	*Ratio 2
		*Total future win shares
		display _b[#1:lnws2cya]/_b[#1:lnwscy]
		*Total contract value
		display _b[#2:lnws2cya]/_b[#2:lnwscy]
	
*TESTS FOR EQUALITY OF THE RATIOS PRESENTED IN TABLE 9.
*(These tests are discussed on page 34 of the thesis.)

*First, execute the SUR regression command that generates Table 7:

quietly xi: sureg (lntotfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy) (lndollars lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy i.tmcy i.cy)

*Then in order to test the ratios of interest, I compared the ratios from one equation to those of another
*comparing one year lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws1cya]/_b[#1:lnwscy]=_b[#2:lnws1cya]/_b[#2:lnwscy]

*comparing two years lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws2cya]/_b[#1:lnwscy]=_b[#2:lnws2cya]/_b[#2:lnwscy]


*TESTS FOR EQUALITY OF RATIOS USING THE RESULTS OF THE REGRESSION
*WITHOUT FIXED EFECTS
*(Not reported in the thesis.)

*First, execute the SUR regression command that generates Table 8:
quietly sureg (lntotfutws lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy) (lndollars lnwscy lnws1cya lnws2cya abs1cy abs2cy aicy aicysq c mpcy mp2cy mp1cy)

*Then, in order to test the ratios of interest, I compared the ratios from one equation to those of another
*comparing one year lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws1cya]/_b[#1:lnwscy]=_b[#2:lnws1cya]/_b[#2:lnwscy]

*comparing two years lagged performance on future performance equal to average yearly contract value
testnl _b[#1:lnws2cya]/_b[#1:lnwscy]=_b[#2:lnws2cya]/_b[#2:lnwscy]

