*Merging Data for Contracts, Regular Stats, and Advanced stats by year
clear

forvalues yy=2007/2012 {
set more off
use ..\cdata\\`yy'contractdataclean 
sort player
merge m:1 player using ..\cdata\\`yy'advancedstatsclean
drop _merge
merge m:1 player using ..\cdata\\`yy'regularstatspgclean
drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to contract year performance
rename age aicy
rename tm tmcy
rename mp mpcy
rename per percy
rename ows owscy
rename dws dwscy
rename ws wscy
rename ws48 ws48cy
rename vorp vorpcy
rename trb trbcy
rename ast astcy
rename stl stlcy
rename bl blcy
rename tov tovcy
rename pf pfcy
rename pts ptscy
*saving each file temporarily
save ..\cdata\\`yy'datatemp.dta, replace

clear

*******adding in performance from two years prior to contract***********************************
use ..\cdata\\`yy'datatemp.dta

local ii=`yy'-2
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to two year prior to contract year performance
rename age ai2cy
rename tm tm2cy
rename mp mp2cy
rename per per2cy
rename ows ows2cy
rename dws dws2cy
rename ws ws2cy
rename ws48 ws482cy
rename vorp vorp2cy
rename trb trb2cy
rename ast ast2cy
rename stl stl2cy
rename bl bl2cy
rename tov tov2cy
rename pf pf2cy
rename pts pts2cy

*saving data again temporarily
save ..\cdata\\`yy'datatemp2.dta, replace
clear

*******adding in performance from one year prior to contract***********************************
use ..\cdata\\`yy'datatemp2.dta

local ii=`yy'-1
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents in year yy
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to one year prior to contract year performance
rename age ai1cy
rename tm tm1cy
rename mp mp1cy
rename per per1cy
rename ows ows1cy
rename dws dws1cy
rename ws ws1cy
rename ws48 ws481cy
rename vorp vorp1cy
rename trb trb1cy
rename ast ast1cy
rename stl stl1cy
rename bl bl1cy
rename tov tov1cy
rename pf pf1cy
rename pts pts1cy

*saving data again temporarily
save ..\cdata\\`yy'datatemp3.dta, replace
clear


*******adding in performance from one year after contract***********************************
use ..\cdata\\`yy'datatemp3.dta

local ii=`yy'+ 1
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to performance one year after contract
rename age aicy1
rename tm tmcy1
rename mp mpcy1
rename per percy1
rename ows owscy1
rename dws dwscy1
rename ws wscy1
rename ws48 ws48cy1
rename vorp vorpcy1
rename trb trbcy1
rename ast astcy1
rename stl stlcy1
rename bl blcy1
rename tov tovcy1
rename pf pfcy1
rename pts ptscy1

*saving data again temporarily
save ..\cdata\\`yy'datatemp4.dta, replace
clear

*******adding in performance from two years after contract***********************************
use ..\cdata\\`yy'datatemp4.dta

local ii=`yy'+ 2
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to two years after contract year performance
rename age aicy2
rename tm tmcy2
rename mp mpcy2
rename per percy2
rename ows owscy2
rename dws dwscy2
rename ws wscy2
rename ws48 ws48cy2
rename vorp vorpcy2
rename trb trbcy2
rename ast astcy2
rename stl stlcy2
rename bl blcy2
rename tov tovcy2
rename pf pfcy2
rename pts ptscy2

*saving data again temporarily
save ..\cdata\\`yy'datatemp5.dta, replace
clear
}
*



***Time to merge all of it into one file using append
use ..\cdata\2007datatemp5.dta
append using ..\cdata\2008datatemp5.dta
append using ..\cdata\2009datatemp5.dta
append using ..\cdata\2010datatemp5.dta
append using ..\cdata\2011datatemp5.dta
append using ..\cdata\2012datatemp5.dta
save ..\cdata\finaldataseta, replace

use ..\cdata\finaldataseta


**dropping all unnecessary variables
drop year c2y c1y cy1 cy2 trbcy astcy stlcy blcy tovcy pfcy ai2cy tm2cy trb2cy ast2cy stl2cy bl2cy tov2cy pf2cy ai1cy tm1cy tov1cy trb1cy ast1cy stl1cy bl1cy pf1cy aicy1 tmcy1
drop trbcy1 astcy1 stlcy1 blcy1 tovcy1 pfcy1 aicy2 tmcy2 trbcy2 vorpcy2 astcy2 stlcy2 blcy2 tovcy2 pfcy2 vorpcy1 vorpcy vorp1cy vorp2cy percy per2cy per1cy
drop percy1 percy2 owscy ows2cy ows1cy owscy1 owscy2 dwscy dws2cy dws1cy dwscy1 dwscy2 ws48cy ws482cy ws481cy ws48cy1 ws48cy2 ptscy pts2cy pts1cy ptscy1 ptscy2


*creating natural log of variables that are very right skewed, namely duration, win shares, dollars, and points
**note: since the lowest value of win share during any season is -1.5 I will add two to all win share values to eliminate negative values

gen lnduration = ln(duration)

gen lnwscy = ln(wscy + 2)
gen lnws2cy = ln(ws2cy + 2)
gen lnws1cy = ln(ws1cy + 2)
gen lnwscy1 = ln(wscy1 + 2)
gen lnwscy2 = ln(wscy2 + 2)


**replacing missing values of lagged win share with 0s and adding in dummy variables to model this appropriately
gen lnws2cya=lnws2cy
replace lnws2cya=0 if ws2cy==.
gen lnws1cya=lnws1cy
replace lnws1cya=0 if ws1cy==.

gen abs1cy=0
replace abs1cy=1 if ws1cy==.

gen abs2cy=0
replace abs2cy=1 if ws2cy==.

**eliminating missing values for minutes played in seasons prior to contract year
replace  mp1cy=0 if mp1cy==.
replace  mp2cy=0 if mp2cy==.

gen lndollars = ln(dollars)

gen lnfutws =  (lnwscy1 + lnwscy2)/2
replace lnfutws = lnwscy1 if lnwscy2 == .
replace lnfutws = lnwscy2 if lnwscy1 == .

**dropping values who have empty lnfutws as their contracts are outside of the desired window for determining contract rationality as they have no future performance data
drop if lnfutws==.

gen lnavgyrlcon = ln(avgyrlcontract)

save ..\cdata\finaldataseta, replace

**creating dummy variables for position 
gen c = 0
replace c = 1 if pos == "C"

gen pg = 0
replace pg = 1 if pos == "PG"

gen pf = 0
replace pf = 1 if pos == "PF"

gen sg = 0
replace sg = 1 if pos == "SG"

gen sf = 0
replace sf = 1 if pos == "SF"


*and creating an age^2 term to allow for non-linearity
gen aicysq= aicy*aicy

*finally saving the data set I will use for methodology A of my analysis 
save ..\cdata\finaldataseta, replace

****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
*Merging Data for Contracts, Regular Stats, and Advanced stats by year for methodology B 
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

clear

forvalues yy=2007/2012 {
set more off
use ..\cdata\\`yy'contractdataclean 
sort player
merge m:1 player using ..\cdata\\`yy'advancedstatsclean
drop _merge
merge m:1 player using ..\cdata\\`yy'regularstatspgclean
drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to contract year performance
rename age aicy
rename tm tmcy
rename mp mpcy
rename per percy
rename ows owscy
rename dws dwscy
rename ws wscy
rename ws48 ws48cy
rename vorp vorpcy
rename trb trbcy
rename ast astcy
rename stl stlcy
rename bl blcy
rename tov tovcy
rename pf pfcy
rename pts ptscy
*saving each file temporarily
save ..\cdata\\`yy'datatemp.dta, replace

clear

*******adding in performance from two years prior to contract***********************************
use ..\cdata\\`yy'datatemp.dta

local ii=`yy'-2
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to two year prior to contract year performance
rename age ai2cy
rename tm tm2cy
rename mp mp2cy
rename per per2cy
rename ows ows2cy
rename dws dws2cy
rename ws ws2cy
rename ws48 ws482cy
rename vorp vorp2cy
rename trb trb2cy
rename ast ast2cy
rename stl stl2cy
rename bl bl2cy
rename tov tov2cy
rename pf pf2cy
rename pts pts2cy

*saving data again temporarily
save ..\cdata\\`yy'datatemp2.dta, replace
clear

*******adding in performance from one year prior to contract***********************************
use ..\cdata\\`yy'datatemp2.dta

local ii=`yy'-1
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents in year yy
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to one year prior to contract year performance
rename age ai1cy
rename tm tm1cy
rename mp mp1cy
rename per per1cy
rename ows ows1cy
rename dws dws1cy
rename ws ws1cy
rename ws48 ws481cy
rename vorp vorp1cy
rename trb trb1cy
rename ast ast1cy
rename stl stl1cy
rename bl bl1cy
rename tov tov1cy
rename pf pf1cy
rename pts pts1cy

*saving data again temporarily
save ..\cdata\\`yy'datatemp3.dta, replace
clear


*******adding in performance from one year after contract***********************************
use ..\cdata\\`yy'datatemp3.dta

local ii=`yy'+ 1
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to performance one year after contract
rename age aicy1
rename tm tmcy1
rename mp mpcy1
rename per percy1
rename ows owscy1
rename dws dwscy1
rename ws wscy1
rename ws48 ws48cy1
rename vorp vorpcy1
rename trb trbcy1
rename ast astcy1
rename stl stlcy1
rename bl blcy1
rename tov tovcy1
rename pf pfcy1
rename pts ptscy1

*saving data again temporarily
save ..\cdata\\`yy'datatemp4.dta, replace
clear
*

*******adding in performance from two years after contract***********************************
use ..\cdata\\`yy'datatemp4.dta

local ii=`yy'+ 2
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to two years after contract year performance
rename age aicy2
rename tm tmcy2
rename mp mpcy2
rename per percy2
rename ows owscy2
rename dws dwscy2
rename ws wscy2
rename ws48 ws48cy2
rename vorp vorpcy2
rename trb trbcy2
rename ast astcy2
rename stl stlcy2
rename bl blcy2
rename tov tovcy2
rename pf pfcy2
rename pts ptscy2

*saving data again temporarily
save ..\cdata\\`yy'datatemp5.dta, replace
clear
}
*

*******adding in performance from three years after contract***********************************
forvalues yy=2007/2011 {
set more off

use ..\cdata\\`yy'datatemp5.dta

local ii=`yy'+ 3
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to three years after contract year performance
rename age aicy3
rename tm tmcy3
rename mp mpcy3
rename per percy3
rename ows owscy3
rename dws dwscy3
rename ws wscy3
rename ws48 ws48cy3
rename vorp vorpcy3
rename trb trbcy3
rename ast astcy3
rename stl stlcy3
rename bl blcy3
rename tov tovcy3
rename pf pfcy3
rename pts ptscy3

*saving data again temporarily
save ..\cdata\\`yy'datatemp6.dta, replace
clear
}
*

*******adding in performance from four years after contract***********************************
forvalues yy=2007/2010 {
set more off

use ..\cdata\\`yy'datatemp6.dta

local ii=`yy'+ 4
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to four years after contract year performance
rename age aicy4
rename tm tmcy4
rename mp mpcy4
rename per percy4
rename ows owscy4
rename dws dwscy4
rename ws wscy4
rename ws48 ws48cy4
rename vorp vorpcy4
rename trb trbcy4
rename ast astcy4
rename stl stlcy4
rename bl blcy4
rename tov tovcy4
rename pf pfcy4
rename pts ptscy4

*saving data again temporarily
save ..\cdata\\`yy'datatemp7.dta, replace
clear
}
*

*******adding in performance from five years after contract***********************************
forvalues yy=2007/2009 {
set more off

use ..\cdata\\`yy'datatemp7.dta

local ii=`yy'+ 5
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to five years after contract year performance
rename age aicy5
rename tm tmcy5
rename mp mpcy5
rename per percy5
rename ows owscy5
rename dws dwscy5
rename ws wscy5
rename ws48 ws48cy5
rename vorp vorpcy5
rename trb trbcy5
rename ast astcy5
rename stl stlcy5
rename bl blcy5
rename tov tovcy5
rename pf pfcy5
rename pts ptscy5

*saving data again temporarily
save ..\cdata\\`yy'datatemp8.dta, replace
clear
}
*


*******adding in performance from six years after contract***********************************
forvalues yy=2007/2008 {
set more off

use ..\cdata\\`yy'datatemp8.dta

local ii=`yy'+ 6
	merge m:1 player using ..\cdata\\`ii'advancedstatsclean
	drop _merge
	merge m:1 player using ..\cdata\\`ii'regularstatspgclean
	drop _merge
*eliminating data for players who were not free agents
drop if year==. 
drop if duration==.
*renaming variables so I know they correspond to six years after contract year performance
rename age aicy6
rename tm tmcy6
rename mp mpcy6
rename per percy6
rename ows owscy6
rename dws dwscy6
rename ws wscy6
rename ws48 ws48cy6
rename vorp vorpcy6
rename trb trbcy6
rename ast astcy6
rename stl stlcy6
rename bl blcy6
rename tov tovcy6
rename pf pfcy6
rename pts ptscy6

*saving data again temporarily
save ..\cdata\\`yy'datatemp9.dta, replace
clear
}
*

***Time to merge all of it into one file using append
use ..\cdata\2007datatemp9.dta
append using ..\cdata\2008datatemp9.dta
append using ..\cdata\2009datatemp8.dta
append using ..\cdata\2010datatemp7.dta
append using ..\cdata\2011datatemp6.dta
append using ..\cdata\2012datatemp5.dta
save ..\cdata\finaldatasetb, replace

use ..\cdata\finaldatasetb


**dropping all unnecessary variables
drop year c2y c1y cy1 cy2 trbcy astcy stlcy blcy tovcy pfcy ai2cy tm2cy trb2cy ast2cy stl2cy bl2cy tov2cy pf2cy ai1cy tm1cy tov1cy trb1cy ast1cy stl1cy bl1cy pf1cy aicy1 tmcy1
drop trbcy1 astcy1 stlcy1 blcy1 tovcy1 pfcy1 aicy2 tmcy2 trbcy2 vorpcy2 astcy2 stlcy2 blcy2 tovcy2 pfcy2 vorpcy1 vorpcy vorp1cy vorp2cy percy per2cy per1cy
drop percy1 percy2 owscy ows2cy ows1cy owscy1 owscy2 dwscy dws2cy dws1cy dwscy1 dwscy2 ws48cy ws482cy ws481cy ws48cy1 ws48cy2 ptscy pts2cy pts1cy ptscy1 ptscy2
drop percy3 owscy3 dwscy3 ws48cy3 ptscy3 vorpcy3 percy3 astcy3 stlcy3 blcy3 tovcy3 pfcy3 trbcy3 tmcy3 aicy3 percy4 owscy4 dwscy4 ws48cy4 ptscy4 vorpcy4 percy4 
drop astcy4 stlcy4 blcy4 tovcy4 pfcy4 trbcy4 tmcy4 aicy4 percy5 owscy5 dwscy5 ws48cy5 ptscy5 vorpcy5 percy5 astcy5 stlcy5 blcy5 tovcy5 pfcy5 trbcy5 tmcy5 aicy5
drop percy6 owscy6 dwscy6 ws48cy6 ptscy6 vorpcy6 percy6 astcy6 stlcy6 blcy6 tovcy6 pfcy6 trbcy6 tmcy6 aicy6 avgyrlcontract

*creating natural log of variables that are very right skewed, namely duration, win shares, dollars, and points
**note: since the lowest value of win share during any season is -1.5 I will add two to all win share values to eliminate negative values

gen lnduration = ln(duration)

*getting rid of 0's for future win share values
replace wscy1 = 0 if wscy1 == .
replace wscy1 = 0 if wscy2 == .
replace wscy1 = 0 if wscy3 == .
replace wscy1 = 0 if wscy4 == .
replace wscy1 = 0 if wscy5 == .
replace wscy1 = 0 if wscy6 == .


gen lnwscy = ln(wscy + 2)
gen lnws2cy = ln(ws2cy + 2)
gen lnws1cy = ln(ws1cy + 2)
gen lnwscy1 = ln(wscy1 + 2)
gen lnwscy2 = ln(wscy2 + 2)
gen lnwscy3 = ln(wscy3 + 2)
gen lnwscy4 = ln(wscy4 + 2)
gen lnwscy5 = ln(wscy5 + 2)
gen lnwscy6 = ln(wscy6 + 2)

**adding in 0s for missing lagged performance variables so these values are not left out of the regression and the dummies to model this appropriately
gen lnws2cya=lnws2cy
replace lnws2cya=0 if ws2cy==.
gen lnws1cya=lnws1cy
replace lnws1cya=0 if ws1cy==.

gen abs1cy=0
replace abs1cy=1 if ws1cy==.

gen abs2cy=0
replace abs2cy=1 if ws2cy==.

**eliminating missing values for minutes played in seasons prior to contract year
replace  mp1cy=0 if mp1cy==.
replace  mp2cy=0 if mp2cy==.

gen lndollars = ln(dollars)

*now generating the natural logged future win share variable 
gen lntotfutws =  0
replace lntotfutws = lnwscy1 if duration==1
replace lntotfutws = lnwscy1 + lnwscy2 if duration==2
replace lntotfutws = lnwscy1 + lnwscy2 + lnwscy3 if duration==3
replace lntotfutws = lnwscy1 + lnwscy2 + lnwscy3 + lnwscy4 if duration==4
replace lntotfutws = lnwscy1 + lnwscy2 + lnwscy3 + lnwscy4 + lnwscy5 if duration==5
replace lntotfutws = lnwscy1 + lnwscy2 + lnwscy3 + lnwscy4 + lnwscy5 + lnwscy6 if duration==6

save ..\cdata\finaldatasetb, replace

**creating dummy variables for position 
gen c = 0
replace c = 1 if pos == "C"

gen pg = 0
replace pg = 1 if pos == "PG"

gen pf = 0
replace pf = 1 if pos == "PF"

gen sg = 0
replace sg = 1 if pos == "SG"

gen sf = 0
replace sf = 1 if pos == "SF"

*generating a summed total future win share for the data section only (***NOTE THIS IS NOT WHAT IS USED FOR LNTOTFUTWS)
gen totfutwsDATA =  0
replace totfutwsDATA  = wscy1 if duration==1
replace totfutwsDATA  = wscy1 + wscy2 if duration==2
replace totfutwsDATA  = wscy1 + wscy2 + wscy3 if duration==3
replace totfutwsDATA  = wscy1 + wscy2 + wscy3 + wscy4 if duration==4
replace totfutwsDATA  = wscy1 + wscy2 + wscy3 + wscy4 + wscy5 if duration==5
replace totfutwsDATA  = wscy1 + wscy2 + wscy3 + wscy4 + wscy5 + wscy6 if duration==6

**dropping contract observations that are not completed
drop if cy==2012 & duration>=3
drop if cy==2011 & duration>=4
drop if cy==2010 & duration>=5
drop if cy==2009 & duration>=6

**adding in a squared term for age to allow for non-linearity
gen aicysq= aicy*aicy


*finally saving the data set I will use for my analysis
save ..\cdata\finaldatasetb, replace
